@@ -10,8 +10,8 @@
 #include <QAbstractItemModel>
 #include <QApplication>
 #include <QFont>
-#include <QQmlApplicationEngine>
 #include <QObject>
+#include <QQmlApplicationEngine>
 
 #include <KAboutData>
 #include <KSharedConfig>
@@ -29,7 +29,8 @@ Q_SIGNALS:
     void applicationMouseLeave();
 
 protected:
-    bool eventFilter(QObject *obj, QEvent *event) override {
+    bool eventFilter(QObject *obj, QEvent *event) override
+    {
         if (event->type() == QEvent::Leave) {
             Q_EMIT applicationMouseLeave();
             return true;
@@ -43,15 +44,13 @@ protected:
 class Application : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(QAbstractItemModel* colorSchemesModel READ colorSchemesModel CONSTANT)
+    Q_PROPERTY(QAbstractItemModel *colorSchemesModel READ colorSchemesModel CONSTANT)
     Q_PROPERTY(QUrl configFilePath READ configFilePath CONSTANT)
     Q_PROPERTY(QUrl configFolderPath READ configFolderPath CONSTANT)
 
 public:
-    explicit Application(int &argc, char **argv, const QString &applicationName);
-    ~Application();
+    static Application *instance();
 
-    int run();
     QUrl configFilePath();
     QUrl configFolderPath();
     Q_INVOKABLE void restoreWindowGeometry(QQuickWindow *window) const;
@@ -67,6 +66,7 @@ public:
     Q_INVOKABLE void activateColorScheme(const QString &name);
     Q_INVOKABLE void openDocs(const QString &page);
     Q_INVOKABLE QStringList getFonts();
+    Q_INVOKABLE int frameworksVersionMinor();
 
     static QString version();
     Q_INVOKABLE static bool hasYoutubeDl();
@@ -75,23 +75,31 @@ public:
     Q_INVOKABLE static QString formatTime(const double time);
     Q_INVOKABLE static QString mimeType(const QUrl &url);
 
+    QCommandLineParser *parser() const;
+
 Q_SIGNALS:
     void qmlApplicationMouseLeave();
     void error(const QString &message);
 
 private:
+    explicit Application();
+    ~Application() = default;
+
+    Application(const Application &) = delete;
+    Application &operator=(const Application &) = delete;
+    Application(Application &&) = delete;
+    Application &operator=(Application &&) = delete;
+
     void setupWorkerThread();
     void setupAboutData();
     void setupCommandLineParser();
     void registerQmlTypes();
     void setupQmlSettingsTypes();
-    void setupQmlContextProperties();
-    void aboutApplication();
     QAbstractItemModel *colorSchemesModel();
     QApplication *m_app;
-    QQmlApplicationEngine *m_engine;
     KAboutData m_aboutData;
     KSharedConfig::Ptr m_config;
+    QCommandLineParser *m_parser;
     QMap<int, QString> m_args;
     KColorSchemeManager *m_schemes;
     QString m_systemDefaultStyle;
