@@ -111,7 +111,10 @@ void PlayListModel::getSiblingItems(QString path)
         while (it.hasNext()) {
             QString siblingFile = it.next();
             QFileInfo siblingFileInfo(siblingFile);
-            QUrl siblingUrl(siblingFile);
+            // toPercentEncoding() is needed to get the correct mime type
+            // for files containing the # character and probably other characters too
+            // if the mime type is wrong the file will be ignored
+            QUrl siblingUrl(siblingFile.toUtf8().toPercentEncoding());
             siblingUrl.setScheme(openedUrl.scheme());
             QString mimeType = Application::mimeType(siblingUrl);
             if (siblingFileInfo.exists() && (mimeType.startsWith("video/") || mimeType.startsWith("audio/")) && mimeType != QStringLiteral("audio/x-mpegurl")) {
@@ -252,7 +255,7 @@ void PlayListModel::openM3uFile(const QString &path)
             item = url.toString(QUrl::PreferLocalFile);
         } else {
             // figure out if it's a relative path
-            item = QUrl::fromUserInput(line, QFileInfo(path).absolutePath()).toString(QUrl::PreferLocalFile);
+            item = QUrl::fromUserInput(line, QFileInfo(m3uFile).absolutePath()).toString(QUrl::PreferLocalFile);
         }
         appendItem(item);
         if (item == QUrl(GeneralSettings::lastPlayedFile()).toString(QUrl::PreferLocalFile)) {
