@@ -85,7 +85,7 @@ MpvItem::MpvItem(QQuickItem *parent)
     });
 
     connect(m_playlistModel, &PlayListModel::playingItemChanged, this, [=]() {
-        command(QStringList() << "loadfile" << m_playlistModel->getPath());
+        loadFile(m_playlistModel->getPath());
     });
 
 #if defined(Q_OS_UNIX)
