@@ -9,20 +9,19 @@
 
 #include "mpvcore.h"
 #include "playlistmodel.h"
+#include "track.h"
 #include "tracksmodel.h"
 
 class MpvRenderer;
-class Track;
 
 class MpvItem : public MpvCore
 {
     Q_OBJECT
 
-    Q_PROPERTY(TracksModel* audioTracksModel READ audioTracksModel NOTIFY audioTracksModelChanged)
-    Q_PROPERTY(TracksModel* subtitleTracksModel READ subtitleTracksModel NOTIFY subtitleTracksModelChanged)
-    Q_PROPERTY(PlayListModel* playlistModel READ playlistModel WRITE setPlaylistModel NOTIFY playlistModelChanged)
-    Q_PROPERTY(QString playlistTitle READ playlistTitle WRITE setPlaylistTitle NOTIFY playlistTitleChanged)
-    Q_PROPERTY(QString playlistUrl READ playlistUrl WRITE setPlaylistUrl NOTIFY playlistUrlChanged)
+    Q_PROPERTY(TracksModel *audioTracksModel READ audioTracksModel NOTIFY audioTracksModelChanged)
+    Q_PROPERTY(TracksModel *subtitleTracksModel READ subtitleTracksModel NOTIFY subtitleTracksModelChanged)
+    Q_PROPERTY(PlayListModel *playlistModel READ playlistModel WRITE setPlaylistModel NOTIFY playlistModelChanged)
+    Q_PROPERTY(PlayListProxyModel *playlistProxyModel READ playlistProxyModel WRITE setPlaylistProxyModel NOTIFY playlistProxyModelChanged)
     Q_PROPERTY(QString mediaTitle READ mediaTitle NOTIFY mediaTitleChanged)
     Q_PROPERTY(double position READ position WRITE setPosition NOTIFY positionChanged)
     Q_PROPERTY(double duration READ duration NOTIFY durationChanged)
@@ -36,20 +35,12 @@ class MpvItem : public MpvCore
     Q_PROPERTY(int audioId READ audioId WRITE setAudioId NOTIFY audioIdChanged)
     Q_PROPERTY(int subtitleId READ subtitleId WRITE setSubtitleId NOTIFY subtitleIdChanged)
     Q_PROPERTY(int secondarySubtitleId READ secondarySubtitleId WRITE setSecondarySubtitleId NOTIFY secondarySubtitleIdChanged)
-    Q_PROPERTY(int contrast READ contrast WRITE setContrast NOTIFY contrastChanged)
-    Q_PROPERTY(int brightness READ brightness WRITE setBrightness NOTIFY brightnessChanged)
-    Q_PROPERTY(int gamma READ gamma WRITE setGamma NOTIFY gammaChanged)
-    Q_PROPERTY(int saturation READ saturation WRITE setSaturation NOTIFY saturationChanged)
 
+    PlayListProxyModel *playlistProxyModel();
+    void setPlaylistProxyModel(PlayListProxyModel *model);
     PlayListModel *playlistModel();
     void setPlaylistModel(PlayListModel *model);
 
-    QString playlistTitle();
-    void setPlaylistTitle(const QString &title);
-
-    const QString &playlistUrl() const;
-    void setPlaylistUrl(const QString &_playlistUrl);
-
     QString mediaTitle();
 
     double position();
@@ -86,24 +77,11 @@ class MpvItem : public MpvCore
     int secondarySubtitleId();
     void setSecondarySubtitleId(int value);
 
-    int contrast();
-    void setContrast(int value);
-
-    int brightness();
-    void setBrightness(int value);
-
-    int gamma();
-    void setGamma(int value);
-
-    int saturation();
-    void setSaturation(int value);
-
 public:
-    MpvItem(QQuickItem * parent = nullptr);
+    explicit MpvItem(QQuickItem *parent = nullptr);
     ~MpvItem() = default;
 
-    Q_INVOKABLE void loadFile(const QString &file, bool updateLastPlayedFile = true);
-    Q_INVOKABLE void getYouTubePlaylist(const QString &path);
+    Q_INVOKABLE void loadFile(const QString &file);
     Q_INVOKABLE void saveTimePosition();
     Q_INVOKABLE double loadTimePosition();
     Q_INVOKABLE void resetTimePosition();
@@ -114,6 +92,7 @@ Q_SIGNALS:
     void audioTracksModelChanged();
     void subtitleTracksModelChanged();
     void playlistModelChanged();
+    void playlistProxyModelChanged();
     void playlistTitleChanged();
     void playlistUrlChanged();
     void mediaTitleChanged();
@@ -129,14 +108,9 @@ Q_SIGNALS:
     void audioIdChanged();
     void subtitleIdChanged();
     void secondarySubtitleIdChanged();
-    void contrastChanged();
-    void brightnessChanged();
-    void gammaChanged();
-    void saturationChanged();
     void fileStarted();
     void fileLoaded();
     void endFile(QString reason);
-    void youtubePlaylistLoaded();
     void syncConfigValue(QString path, QString group, QString key, QVariant value);
 
     // signals used for mpris
@@ -152,13 +126,12 @@ private:
     QString md5(const QString &str);
     TracksModel *m_audioTracksModel;
     TracksModel *m_subtitleTracksModel;
-    QMap<int, Track*> m_subtitleTracks;
-    QMap<int, Track*> m_audioTracks;
+    QMap<int, Track *> m_subtitleTracks;
+    QMap<int, Track *> m_audioTracks;
     QList<int> m_secondsWatched;
     double m_watchPercentage;
     PlayListModel *m_playlistModel;
-    QString m_playlistTitle;
-    QString m_playlistUrl;
+    PlayListProxyModel *m_playlistProxyModel;
     QString m_file;
 };
 
