@@ -20,9 +20,8 @@
 #include <KConfigGroup>
 #include <KFileMetaData/ExtractorCollection>
 #include <KFileMetaData/SimpleExtractionResult>
-#include <kconfig_version.h>
 
-Worker* Worker::instance()
+Worker *Worker::instance()
 {
     static Worker w;
     return &w;
@@ -32,13 +31,12 @@ void Worker::getMetaData(int index, const QString &path)
 {
     QString mimeType = Application::mimeType(QUrl(path));
     KFileMetaData::ExtractorCollection exCol;
-    QList<KFileMetaData::Extractor*> extractors = exCol.fetchExtractors(mimeType);
-    KFileMetaData::SimpleExtractionResult result(path, mimeType,
-                                                 KFileMetaData::ExtractionResult::ExtractMetaData);
+    QList<KFileMetaData::Extractor *> extractors = exCol.fetchExtractors(mimeType);
+    KFileMetaData::SimpleExtractionResult result(path, mimeType, KFileMetaData::ExtractionResult::ExtractMetaData);
     if (extractors.size() == 0) {
         return;
     }
-    KFileMetaData::Extractor* ex = extractors.first();
+    KFileMetaData::Extractor *ex = extractors.first();
     ex->extract(&result);
 #if KCONFIG_VERSION >= QT_VERSION_CHECK(5, 89, 0)
     auto properties = result.properties(KFileMetaData::MultiMap);
@@ -66,29 +64,17 @@ void Worker::makePlaylistThumbnail(const QString &id, int width)
 
     // load existing thumbnail if there is one
     if (QFileInfo::exists(cachedFilePath) && image.load(cachedFilePath)) {
-        Q_EMIT thumbnailSuccess(image);
+        Q_EMIT thumbnailSuccess(id, image);
         return;
     }
 
-    FrameDecoder frameDecoder(file.toLocalFile(), nullptr);
-    if (!frameDecoder.getInitialized()) {
-        return;
-    }
-    //before seeking, a frame has to be decoded
-    if (!frameDecoder.decodeVideoFrame()) {
-        return;
-    }
-
-    int secondToSeekTo = frameDecoder.getDuration() * 20 / 100;
-    frameDecoder.seek(secondToSeekTo);
-
-    frameDecoder.getScaledVideoFrame(width, true, image);
+    image = frameToImage(id, width);
 
     if (image.isNull()) {
         qDebug() << QStringLiteral("Failed to create thumbnail for file: %1").arg(id);
         return;
     }
-    Q_EMIT thumbnailSuccess(image);
+    Q_EMIT thumbnailSuccess(id, image);
 
     QFileInfo fi(cachedFilePath);
     // create folders where the file will be saved
@@ -99,6 +85,25 @@ void Worker::makePlaylistThumbnail(const QString &id, int width)
     }
 }
 
+QImage Worker::frameToImage(const QString &id, int width)
+{
+    QImage image;
+    FrameDecoder frameDecoder(id, nullptr);
+    if (!frameDecoder.getInitialized()) {
+        return image;
+    }
+    // before seeking, a frame has to be decoded
+    if (!frameDecoder.decodeVideoFrame()) {
+        return image;
+    }
+
+    int secondToSeekTo = frameDecoder.getDuration() * 20 / 100;
+    frameDecoder.seek(secondToSeekTo);
+    frameDecoder.getScaledVideoFrame(width, true, image);
+
+    return image;
+}
+
 void Worker::syncConfigValue(QString path, QString group, QString key, QVariant value)
 {
     if (!m_cachedConf || m_cachedConf->name() != path) {
@@ -108,3 +113,5 @@ void Worker::syncConfigValue(QString path, QString group, QString key, QVariant
     m_cachedConf->group(group).writeEntry(key, value);
     m_cachedConf->sync();
 }
+
+#include "moc_worker.cpp"
